@@ -23,7 +23,7 @@ use vars qw( @ISA $VERSION $ATTRIBUTION $drh $err $errstr $sqlstate );
 
 @ISA =   qw( DBD::File );
 
-$VERSION  = "0.41";
+$VERSION     = "0.45";
 $ATTRIBUTION = "DBD::CSV $DBD::CSV::VERSION by H.Merijn Brand";
 
 $err      = 0;		# holds error code   for DBI::err
@@ -71,7 +71,7 @@ sub connect
 {
     my ($drh, $dbname, $user, $auth, $attr) = @_;
     my $dbh = $drh->DBD::File::dr::connect ($dbname, $user, $auth, $attr);
-    $dbh->{Active} = 1;
+    $dbh and $dbh->{Active} = 1;
     $dbh;
     } # connect
 
@@ -138,6 +138,22 @@ sub get_csv_versions
     return sprintf "%s using %s", $dbh->{csv_version}, $dtype;
     } # get_csv_versions 
 
+sub get_info
+{
+    my ($dbh, $info_type) = @_;
+    require  DBD::CSV::GetInfo;
+    my $v = $DBD::CSV::GetInfo::info{int ($info_type)};
+    ref $v eq "CODE" and $v = $v->($dbh);
+    return $v;
+    } # get_info
+
+sub type_info_all
+{
+    my $dbh = shift;
+    require   DBD::CSV::TypeInfo;
+    return [@$DBD::CSV::TypeInfo::type_info_all];
+    } # type_info_all
+
 # --- STATEMENT ----------------------------------------------------------------
 
 package DBD::CSV::st;
@@ -320,6 +336,8 @@ sub fetch_row
 	$csv->eof and return;
 
 	my @diag = _csv_diag ($csv);
+	$diag[0] == 2012 and return; # Also EOF (broken in Text::CSV_XS-1.10)
+
 	my $file = $tbl->{f_fqfn};
 	croak "Error $diag[0] while reading file $file: $diag[1] \@ line $diag[3] pos $diag[2]";
 	}
@@ -359,23 +377,24 @@ DBD::CSV - DBI driver for CSV files
 
     use DBI;
     # See "Creating database handle" below
-    $dbh = DBI->connect ("dbi:CSV:") or
-	die "Cannot connect: $DBI::errstr";
+    $dbh = DBI->connect ("dbi:CSV:", undef, undef, {
+        f_ext      => ".csv/r",
+        RaiseError => 1,
+        }) or die "Cannot connect: $DBI::errstr";
 
     # Simple statements
-    $dbh->do ("CREATE TABLE a (id INTEGER, name CHAR (10))") or
-	die "Cannot prepare: " . $dbh->errstr ();
+    $dbh->do ("CREATE TABLE foo (id INTEGER, name CHAR (10))");
 
     # Selecting
-    $dbh->{RaiseError} = 1;
     my $sth = $dbh->prepare ("select * from foo");
     $sth->execute;
-    while (my @row = $sth->fetchrow_array) {
-	print "id: $row[0], name: $row[1]\n";
+    $sth->bind_columns (\my ($id, $name));
+    while ($sth->fetch) {
+	print "id: $id, name: $name\n";
 	}
 
     # Updates
-    my $sth = $dbh->prepare ("UPDATE a SET name = ? WHERE id = ?");
+    my $sth = $dbh->prepare ("UPDATE foo SET name = ? WHERE id = ?");
     $sth->execute ("DBI rocks!", 1);
     $sth->finish;
 
@@ -879,12 +898,12 @@ I<csv_escape_char> are corresponding to the respective attributes of the
 I<csv_class> (usually Text::CSV_CS) object. You may want to set these
 attributes if you have unusual CSV files like F</etc/passwd> or MS Excel
 generated CSV files with a semicolon as separator. Defaults are
-"\015\012", ';', '"' and '"', respectively.
+C<\015\012>", C<,>, C<"> and C<">, respectively.
 
 The I<csv_eol> attribute defines the end-of-line pattern, which is better
 known as a record separator pattern since it separates records.  The default
-is windows-style end-of-lines "\015\012" for output (writing) and unset for
-input (reading), so if on unix you may want to set this to newline ("\n")
+is windows-style end-of-lines C<\015\012> for output (writing) and unset for
+input (reading), so if on unix you may want to set this to newline (C<\n>)
 like this:
 
   $dbh->{csv_eol} = "\n";
@@ -1177,7 +1196,7 @@ Previous maintainer was Jeff Zucker
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by H.Merijn Brand
+Copyright (C) 2009-2014 by H.Merijn Brand
 Copyright (C) 2004-2009 by Jeff Zucker
 Copyright (C) 1998-2004 by Jochen Wiedmann
 
